@@ -25,10 +25,11 @@ class QDBusMessage;
  *
  * The base class for KDED modules.
  *
- * KDED modules are realized as shared
- * libraries that are loaded on-demand into kded at runtime.
+ * KDED modules are constructed as shared libraries that are loaded on-demand
+ * into the kded daemon at runtime.
  *
- * See kdelibs/kded/HOWTO for documentation about writing kded modules.
+ * See https://invent.kde.org/frameworks/kded/-/blob/master/docs/HOWTO
+ * for documentation about writing kded modules.
  *
  * @author Waldo Bastian <bastian@kde.org>
  */
@@ -45,7 +46,7 @@ public:
      */
     explicit KDEDModule(QObject *parent = nullptr);
 
-    virtual ~KDEDModule();
+    ~KDEDModule() override;
 
     /**
      * Sets the name of the module, and uses it to register the module to D-Bus.
@@ -65,11 +66,6 @@ public:
     static QString moduleForMessage(const QDBusMessage &message);
 
 Q_SIGNALS:
-    /**
-     * Emitted when the module is being deleted.
-     */
-    void moduleDeleted(KDEDModule *);
-
     /**
      * Emitted when a mainwindow registers itself.
      */
